@@ -1,7 +1,7 @@
 `pdredge` <-
 function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 	rank = "AICc", fixed = NULL, m.max = NA, m.min = 0, subset, marg.ex = NULL,
-	trace = FALSE, varying, extra, check = FALSE,  ...) {
+	trace = FALSE, varying, extra, ct.args = NULL, check = FALSE,  ...) {
 #FIXME: m.max cannot be 0 - e.g. for intercept only model
 
 	qlen <- 25L
@@ -12,14 +12,13 @@ function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 		clusterCall <- get("clusterCall")
 		clusterApply <- get("clusterApply")
 		clusterCall(cluster, "require", "MuMIn", character.only = TRUE)
-
 		clusterCall(cluster, assign, "assignFromNs", function(name, asName = name,
 			ns = "MuMIn") {
 			assign(asName, get(name, loadNamespace(ns)), envir = .GlobalEnv)
 			invisible(NULL)
 		}, envir = .GlobalEnv)
 
-		clusterCall(cluster, "assignFromNs", ".getLogLik")
+		clusterCall(cluster, "assignFromNs", ".getLik")
 		clusterCall(cluster, "assignFromNs", "tryCatchWE")
 		clusterCall(cluster, "assignFromNs", "matchCoef")
 		clusterCall(cluster, "assignFromNs", "parGetMsRow")
@@ -48,7 +47,7 @@ function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 		#"For objects without a 'call' component the call to the fitting function \n",
 		#" must be used directly as an argument to 'dredge'.")
 		# NB: this is unlikely to happen:
-		if(!exists(as.character(gmCall[[1L]]), parent.frame(), mode="function"))
+		if(!exists(as.character(gmCall[[1L]]), parent.frame(), mode = "function"))
 			 stop("could not find function '", gmCall[[1L]], "'")
 	} else {
 		# if 'update' method does not expand dots, we have a problem
@@ -81,10 +80,13 @@ function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 
 	if(length(grep(":", all.vars(reformulate(allTerms))) > 0L))
 		stop("variable names in the formula cannot contain \":\"")
-	logLik <- .getLogLik()
+	
+    LL <- .getLik(global.model)
+	logLik <- LL$logLik
+	lLName <- LL$name
 
 	# parallel: check whether the models would be identical:
-	if(doParallel) testUpdatedObj(cluster, global.model, gmCall, do.eval = check)
+	if(doParallel && check) testUpdatedObj(cluster, global.model, gmCall, level = check)
 
 	# Check for na.omit
 	if (!is.null(gmCall$na.action) &&
@@ -102,7 +104,7 @@ function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 	if(isTRUE(rankArgs$REML) || (isTRUE(.isREMLFit(global.model)) && is.null(rankArgs$REML)))
 		warning("comparing models fitted by REML")
 
-	if (beta && is.null(tryCatch(beta.weights(global.model), error=function(e) NULL,
+	if (beta && is.null(tryCatch(beta.weights(global.model), error = function(e) NULL,
 		warning = function(e) NULL))) {
 		warning("do not know how to calculate beta weights for ",
 				class(global.model)[1L], ", argument 'beta' ignored")
@@ -133,8 +135,9 @@ function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 	gmFormulaEnv <- environment(as.formula(formula(global.model), env = gmEnv))
 	# TODO: gmEnv <- gmFormulaEnv ???
 
-	### BEGIN:
-	## varying BEGIN
+	### BEGIN Manage 'varying'
+	## @param:	varying
+	## @value:	varying, varying.names, variants, nvariants, nvarying
 	if(!missing(varying) && !is.null(varying)) {
 		nvarying <- length(varying)
 		varying.names <- names(varying)
@@ -148,10 +151,11 @@ function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 		nvariants <- 1L
 		nvarying <- 0L
 	}
+	## END: varying
 
-	## varying END
-
-	## extra BEGIN
+	## BEGIN Manage 'extra'
+	## @param:	extra, global.model, gmFormulaEnv, 
+	## @value:	extra, nextra, extraNames, null.fit
 	if(!missing(extra) && length(extra) != 0L) {
 		extraNames <- sapply(extra, function(x) switch(mode(x),
 			call = deparse(x[[1L]]), name = deparse(x), character = , x))
@@ -177,12 +181,13 @@ function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 		nextra <- 0L
 		extraNames <- character(0L)
 	}
-	## extra END
+	## END: manage 'extra'
 
 	nov <- as.integer(n.vars - n.fixed)
 	ncomb <- (2L ^ nov) * nvariants
 
-	if(nov > 31L) stop(gettextf("number of predictors (%d) exceeds allowed maximum (31)"), nov, domain = "MuMIn")
+	if(nov > 31L) stop(gettextf("number of predictors (%d) exceeds allowed maximum (31)",
+								nov, domain = "MuMIn"))
 	#if(nov > 10L) warning(gettextf("%d predictors will generate up to %.0f combinations", nov, ncomb))
 	nmax <- ncomb * nvariants
 	if(evaluate) {
@@ -196,17 +201,59 @@ function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 
 	calls <- vector(mode = "list", length = ret.nchunk)
 
-	if(hasSubset <- !missing(subset))  {
-		if(!tryCatch(is.language(subset), error = function(e) FALSE))
+	## BEGIN: Manage 'subset'
+	## @param:	hasSubset, subset, allTerms, interceptLabel, 
+	## @value:	hasSubset, subset
+	if(missing(subset))  {
+		hasSubset <- 1L
+	} else {
+		if(!tryCatch(is.language(subset) || is.matrix(subset), error = function(e) FALSE))
 			subset <- substitute(subset)
-		if(inherits(subset, "formula")) {
-			if (subset[[1L]] != "~" || length(subset) != 2L)
-				stop("'subset' should be a one-sided formula")
-			subset <- subset[[2L]]
+
+		if(is.matrix(subset)) {
+			dn <- dimnames(subset)
+			#at <- allTerms[!(allTerms %in% interceptLabel)]
+			n <- length(allTerms)
+			if(is.null(dn) || any(sapply(dn, is.null))) {
+				di <- dim(subset)
+				if(any(di != n)) stop("unnamed 'subset' matrix does not have ",
+					"both dimensions equal to number of terms in 'global.model': %d", n)
+				dimnames(subset) <- list(allTerms, allTerms)
+			} else {
+				if(!all(unique(unlist(dn)) %in% allTerms))
+					warning("at least some dimnames of 'subset' matrix do not ",
+					"match term names in 'global.model'")
+				subset <- matrix(subset[match(allTerms, rownames(subset)),
+					match(allTerms, colnames(subset))],
+					dimnames = list(allTerms, allTerms),
+					nrow = n, ncol = n)
+			}
+			if(any(!is.na(subset[!lower.tri(subset)]))) {
+				warning("non-missing values exist outside the lower triangle of 'subset'")
+				subset[!lower.tri(subset)] <- NA
+			}
+			mode(subset) <- "logical"
+			hasSubset <- 2L # subset as matrix
+		} else {
+			if(inherits(subset, "formula")) {
+				if (subset[[1L]] != "~" || length(subset) != 2L)
+					stop("'subset' formula should be one-sided")
+				subset <- subset[[2L]]
+			}
+			if(!all(all.vars(subset) %in% allTerms))
+				warning("not all terms in 'subset' exist in 'global.model'")
+			subset <- as.expression(subset)
+			
+			subsetExpr <- as.expression(eval(call("substitute", subset[[1L]],
+				env = structure(lapply(1L:length(allTerms), function(i) call("[", as.name("comb"), i)),
+					names = allTerms)), envir = NULL))
+			
+			hasSubset <- 3L # subset as expression
+			ssEnv <- new.env(parent = .GlobalEnv)
 		}
-		if(!all(all.vars(subset) %in% allTerms))
-			warning("not all terms in 'subset' exist in 'global.model'")
-	}
+	} # END: manage 'subset'
+
+	#return(subset)
 
 	comb.sfx <- rep(TRUE, n.fixed)
 	comb.seq <- if(nov != 0L) seq_len(nov) else 0L
@@ -229,7 +276,8 @@ function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 			} else NULL,
 		gmFormulaEnv = gmFormulaEnv
 		)
-
+	
+	
 	# TODO: allow for 'marg.ex' per formula in multi-formula models
 	if(missing(marg.ex) || (!is.null(marg.ex) && is.na(marg.ex))) {
 		newArgs <- makeArgs(global.model, allTerms, rep(TRUE, length(allTerms)),
@@ -247,8 +295,17 @@ function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 	# BEGIN parallel
 	qi <- 0L
 	queued <- vector(qlen, mode = "list")
-	parCommonProps <- list(gmEnv = gmEnv, IC = IC, beta = beta,
-		allTerms = allTerms, nextra = nextra)
+	parCommonProps <- list(gmEnv = gmEnv, IC = IC, 
+		# beta = beta,
+		# allTerms = allTerms, 
+		nextra = nextra,
+		matchCoefCall = as.call(c(list(
+			as.name("matchCoef"), as.name("fit1"), 
+			all.terms = allTerms, beta = beta, 
+			allCoef = TRUE), ct.args))
+		# matchCoefCall = as.call(c(alist(matchCoef, fit1, all.terms = Z$allTerms, 
+		#   beta = Z$beta, allCoef = TRUE), ct.args))
+		)
 	if(nextra) {
 		parCommonProps$applyExtras <- applyExtras
 		parCommonProps$extraResult <- extraResult
@@ -260,7 +317,8 @@ function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 	retColIdx <- if(nvarying) -n.vars - seq_len(nvarying) else TRUE
 
 	warningList <- list()
-	# qlen <- 4 ## DEBUG: !!!!
+
+	####
 
 	prevJComb <- 0L
 	for(iComb in seq.int(ncomb)) {
@@ -270,8 +328,21 @@ function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 			prevJComb <- jComb
 			comb <- c(as.logical(intToBits(jComb - 1L)[comb.seq]), comb.sfx)
 			nvar <- sum(comb) - nInts
-			if(!(nvar > m.max || nvar < m.min) && (!hasSubset || eval(subset,
-				structure(as.list(comb), names = allTerms)))) {
+			
+			
+			# POSITIVE condition for 'pdredge', NEGATIVE for 'dredge':
+			if((nvar >= m.min && nvar <= m.max) && switch(hasSubset,
+					# 1 - no subset, 2 - matrix, 3 - expression
+					TRUE,                                    # 1 
+					all(subset[comb, comb], na.rm = TRUE),   # 2
+					{
+						assign("comb", comb, ssEnv)
+						assign("*nvar*", nvar, ssEnv)
+						eval(subsetExpr, envir = ssEnv, enclos = parent.frame())
+					}  # 3
+					)
+				) {
+
 				newArgs <- makeArgs(global.model, allTerms[comb], comb, argsOptions)
 				formulaList <- if(is.null(attr(newArgs, "formulaList"))) newArgs else
 					attr(newArgs, "formulaList")
@@ -397,7 +468,7 @@ function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 	v <- order(termsOrder)
 	ret[, i] <- ret[, v]
 	allTerms <- allTerms[v]
-	colnames(ret) <- c(allTerms, varying.names, extraNames, "df", "logLik", ICName)
+	colnames(ret) <- c(allTerms, varying.names, extraNames, "df", lLName, ICName)
 
 	if(nvarying) {
 		variant.names <- lapply(varying, function(x)
@@ -437,7 +508,7 @@ function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 		attr(ret, "random.terms") <- attr(allTerms0, "random.terms")
 
 	if(doParallel) clusterCall(cluster, "rm",
-		list = c("parGetMsRow", "clustDredgeProps", ".getLogLik", "tryCatchWE",
+		list = c("parGetMsRow", "clustDredgeProps", ".getLik", "tryCatchWE",
 			"matchCoef", "parGetMsRow"), envir = .GlobalEnv)
 	return(ret)
 } ######
@@ -458,8 +529,10 @@ function(global.model, cluster = NA, beta = FALSE, evaluate = TRUE,
 			extraResult1 <- tmp
 		}
 	} else extraResult1 <- NULL
-	ll <- .getLogLik()(fit1)
-	mcoef <- matchCoef(fit1, all.terms = Z$allTerms, beta = Z$beta, allCoef = TRUE)
+	ll <- .getLik(fit1)$logLik(fit1)
+
+	#mcoef <- matchCoef(fit1, all.terms = Z$allTerms, beta = Z$beta, allCoef = TRUE)
+	mcoef <- eval(Z$matchCoefCall)
 
 	list(value = c(mcoef, extraResult1, df = attr(ll, "df"), ll = ll,
 		ic = Z$IC(fit1)),
